pub async fn serve_metrics(api_url: &str) -> Result<()>Expand description
Starts a server that exposes metrics http like http://localhost:8000/metrics?aws-region=eu-west-1
pub async fn serve_metrics(api_url: &str) -> Result<()>Starts a server that exposes metrics http like http://localhost:8000/metrics?aws-region=eu-west-1